@@ -25,14 +25,16 @@
 #' of \mjseqn{m}, excluding \mjseqn{m}, and \mjseqn{h} is the forecast horizon.
 #' @param C (\mjseqn{n_a \times n_b}) cross-sectional (contemporaneous) matrix
 #' mapping the bottom level series into the higher level ones (or a list
-#' of matrices forming \mjseqn{\textbf{C} = [\textbf{C}_1' \; \textbf{C}_2' \; ... \; \textbf{C}_L']'},
+#' of matrices forming \mjseqn{\mathbf{C} = [\mathbf{C}_1' \; \mathbf{C}_2' \; ... \; \mathbf{C}_L']'},
 #' \mjseqn{1, ..., L} being the number of the cross-sectional upper levels.
 #' @param nl (\mjseqn{L \times 1}) vector containing the number of time series
 #' in each level of the hierarchy (\code{nl[1] = 1}).
 #' @param m Highest available sampling frequency per seasonal cycle (max. order
 #' of temporal aggregation, \mjseqn{m}), or a subset of the \mjseqn{p} factors
 #' of \mjseqn{m}.
-#' @param weights covariance matrix or a vector
+#' @param weights covariance matrix or a vector (weights used in the reconciliation:
+#' either (\mjseqn{n_b \times 1}) for exogenous or (\mjseqn{n \times 1}) for
+#' endogenous constraints).
 #' @param bnaive matrix/vector of naive bts base forecasts
 #' (e.g., seasonal averages, as in Hollyman et al., 2021):
 #' (\mjseqn{h \times n_b}) matrix in the cross-sectional framework;
@@ -150,7 +152,11 @@
 #' @return The function returns the level reconciled forecasts
 #' in case of an elementary hierarchy with one level.
 #' Otherwise it returns a list with
-#' \item{\code{recf}}{the first level reconciled forecasts, if \code{CCC = FALSE}, or the CCC reconciled forecasts.}
+#' \item{\code{recf}}{Level Conditional Coherent (\code{CCC = FALSE}) forecasts
+#' matrix/vector calculated as simple averages of upper level conditional
+#' reconciled forecasts, with either endogenous or exogenous constraints.
+#' If \code{CCC = TRUE} then it is the Combined Conditional Coherent matrix/vector,
+#' as weighted averages of LCC and bottom-up reconciled forecasts.}
 #' \item{\code{levrecf}}{list of level conditional reconciled forecasts (+ BU).}
 #' \item{\code{info} (\code{type="osqp"})}{matrix with some useful indicators (columns)
 #' for each forecast horizon \mjseqn{h} (rows): run time (\code{run_time}), number of iteration,
@@ -480,7 +486,8 @@ lccrec_thf <- function(basef, m, weights, bnaive = NULL,
         return(y)
       })
       out <- list()
-      out$recf <- lev[[1]]
+      #out$recf <- lev[[1]]
+      out$recf <- Reduce("+", lev[-length(lev)])/(length(lev)-1)
       out$levrecf <- lev
       out$info <- info
     }else if(nn_type == "sntz"){
@@ -498,7 +505,8 @@ lccrec_thf <- function(basef, m, weights, bnaive = NULL,
         return(y)
       })
       out <- list()
-      out$recf <- lev[[1]]
+      #out$recf <- lev[[1]]
+      out$recf <- Reduce("+", lev[-length(lev)])/(length(lev)-1)
       out$levrecf <- lev
     }else{
       lev <- lapply(yl, function(x){
@@ -511,7 +519,8 @@ lccrec_thf <- function(basef, m, weights, bnaive = NULL,
         return(y)
       })
       out <- list()
-      out$recf <- lev[[1]]
+      #out$recf <- lev[[1]]
+      out$recf <- Reduce("+", lev[-length(lev)])/(length(lev)-1)
       out$levrecf <- lev
     }
     return(out)
@@ -724,7 +733,8 @@ lccrec_hts <- function(basef, C, nl, weights, bnaive = NULL,
     }else{
       out <- list()
       if(length(info)>0){
-        out$recf <- yl[[1]]
+        #out$recf <- yl[[1]]
+        out$recf <- Reduce("+", yl[-length(yl)])/(length(yl)-1)
         out$levrecf <- yl
         out$info <- info
       }else if(nn_type == "sntz"){
@@ -734,10 +744,12 @@ lccrec_hts <- function(basef, C, nl, weights, bnaive = NULL,
           colnames(out) <- if(is.null(colnames(basef))) paste("serie", 1:n, sep = "") else colnames(basef)
           return(out)
         })
-        out$recf <- yl0[[1]]
+        #out$recf <- yl0[[1]]
+        out$recf <- Reduce("+", yl0[-length(yl0)])/(length(yl0)-1)
         out$levrecf <- yl0
       }else{
-        out$recf <- yl[[1]]
+        #out$recf <- yl[[1]]
+        out$recf <- Reduce("+", yl[-length(yl)])/(length(yl)-1)
         out$levrecf <- yl
       }
       return(out)
@@ -929,7 +941,8 @@ lccrec_ctf <- function(basef, C, nl, m, weights, bnaive = NULL,
       yl <- lapply(yl, v2m_oct, Dh = Dh, n = n,
                    nam = rownames(basef), m = m,
                    kset = kset, h = h)
-      out$recf <- yl[[1]]
+      #out$recf <- yl[[1]]
+      out$recf <- Reduce("+", yl[-length(yl)])/(length(yl)-1)
       out$levrecf <- yl
       out$info <- info
     }else if(nn_type == "sntz"){
@@ -940,13 +953,15 @@ lccrec_ctf <- function(basef, C, nl, m, weights, bnaive = NULL,
       yl <- lapply(yl, v2m_oct, Dh = Dh, n = n,
                    nam = rownames(basef), m = m,
                    kset = kset, h = h)
-      out$recf <- yl[[1]]
+      #out$recf <- yl[[1]]
+      out$recf <- Reduce("+", yl[-length(yl)])/(length(yl)-1)
       out$levrecf <- yl
     }else{
       yl <- lapply(yl, v2m_oct, Dh = Dh, n = n,
                    nam = rownames(basef), m = m,
                    kset = kset, h = h)
-      out$recf <- yl[[1]]
+      #out$recf <- yl[[1]]
+      out$recf <- Reduce("+", yl[-length(yl)])/(length(yl)-1)
       out$levrecf <- yl
     }
     return(out)
